Links
-----

ATSAS
=====

* https://www.embl-hamburg.de/biosaxs/download.html

Dask resources
==============

* https://docs.dask.org/en/latest/setup/hpc.html
* https://jobqueue.dask.org
* https://jobqueue.dask.org/en/latest/generated/dask_jobqueue.SLURMCluster.html

NSLS-II APCluster
=================

* https://nsls2controls.bnl.gov/index.php/APCluster
